@@ -89,6 +89,13 @@ void Kwave::WorkerThread::start()
     QThread::start();
 }
 
+//***************************************************************************
+void Kwave::WorkerThread::cancel()
+{
+    requestInterruption();
+    emit sigCancel();
+}
+
 //***************************************************************************
 int Kwave::WorkerThread::stop(unsigned int timeout)
 {
